/******************************************************************************/
/* A test program and example for an EPSON P300017100 LCD with a SED1330 card */
/*                                                                            */
/* Written by David Toth  (dave@iris.elte.hu)                                 */
/*                                                                            */
/* This program is FREE and comes with ABSOLUTELY NO WARRANTY and NO SUPPORT  */
/* The author refuses any responsibility! All damages, harmful things happen  */
/* to your computer or to you is your responsibility!                         */
/*                                                                            */
/* Please do not write me letters about it is not working or you can't        */
/* compile it (use DJGPP). I'm sure you have a friend who knows how to use    */
/* this source code.                                                          */
/******************************************************************************/

#include <stdio.h>
#include <conio.h>
#include <pc.h>
#include <math.h>

#define WINWIDTH      512             /* Width of your LCD in pixels  */
#define WINHEIGHT      64             /* Height of your LCD in pixels */
#define CENTERX      WINWIDTH/2
#define CENTERY     WINHEIGHT/2
#define RAD            30             /* The size of lines displayed.        */
                                      /* This should be smaller than CENTERX */
                                      /* and CENTERY !                       */
#define LINES          15
#define STEP           3

char screen[WINWIDTH*WINHEIGHT/8];

/* The following is good for 512*64 display only! */
char txt_scr[WINWIDTH*WINHEIGHT/64]=
  "                                                      Text layer"
  "                                                      You should"
  "                                                see this message"
  "                                                     flashing, a"
  "                                                   text message:"
  "                                            'Graphics layer' and"
  "                                                lots of lines..."
  "                                               I hope you do :-)";

void clear_window();
void init_lcd(int);
int writetext(unsigned char*,char*,int,int,int,int,int*,int*);
void draw_line(int,int,int,int,unsigned char*);
unsigned char charset_10x18[257*36];
unsigned char get_hexaarg(char *, int *, int *);

void main(int argc, char *argv[])
{
  float a,b;
  int cnt,cnt2;
  int port_addr=0x34e;
  int port_addr2=0x34c;
  int cnt_val, cnt_ch;
  unsigned char timetest=0, probe=0, usage=0, error=0;

  cnt_val=1;
  while((cnt_val<argc)&&!error)
  {
    if(argv[cnt_val][0]!='-') error=1;
    else
    {
      cnt_ch=1;
      while((argv[cnt_val][cnt_ch]!=0)&&!error)
      {
        switch(argv[cnt_val][cnt_ch])
        {
          case 'p': case 'P':
              cnt_ch++;
              error=get_hexaarg(argv[cnt_val],&cnt_ch,&port_addr);
             break;
          case 't': case 'T':
              switch(argv[cnt_val][cnt_ch+1])
              {
                case '1': timetest=1; cnt_ch+=2; break;
                case '2': probe=1; cnt_ch+=2; break;
                case 't': case 'T':
                        cnt_ch+=2;
                        error=get_hexaarg(argv[cnt_val],&cnt_ch,&port_addr2);
                        break;
                default: error=5; break;
              }
              break;
          default: error=4; break;
        }
      }
      if(!error) cnt_val++;
    }
  }

  switch(error)
  {
    case 1:
      fprintf(stderr,"Error: invalid argument '%s'\n",argv[cnt_val]);
      usage=1; break;
    case 2:
    case 3:
      fprintf(stderr,"Error: in argument '%s'\nError: Port address should be "
        "given as a hexadecimal number starting with 0x!\n",argv[cnt_val]);
      usage=1; break;
    case 4:
      fprintf(stderr,"Error: in argument '%s': unknown switch %c\n",
        argv[cnt_val],argv[cnt_val][cnt_ch]); usage=1; break;
    case 5:
      fprintf(stderr,"Error: in argument '%s': bad usage of switch -t\n",
        argv[cnt_val]); usage=1; break;
    default: break;
  }

  if(usage)
  {
    cnt_val=0; cnt_ch=0;
    while(argv[0][cnt_val]!=0)
    {
      if(argv[0][cnt_val]=='/') cnt_ch=cnt_val+1;
      cnt_val++;
    }
    fprintf(stderr,
     "Usage: %s -p[portaddr] -t1 -t2 -tt[portaddr]\n"
     "       -p[portaddr]  defines the address of the SED1330 ISA card\n"
     "                     ( default is -p0x%04X )\n"
     "       -t1           force timetest\n"
     "       -t2           force probe\n"
     "       -tt[portaddr] defines any other address used to test the SED1330 "
     "ISA\n"
     "                     card ( default is -tt0x%04X ). Make sure there are "
     "no\n"
     "                     resource using this address!\n",
         &argv[0][cnt_ch],port_addr,port_addr2);
    exit(-1);
  }

  fprintf(stderr,"ISA base: 0x%04X\n",port_addr);
  if(timetest)
    fprintf(stderr," running timetest, test address: 0x%04X\n",port_addr2);
  else if(probe)
    fprintf(stderr," running probe, test address: 0x%04X\n",port_addr2);
  fflush(stderr);

  printf("If you are sure you want to continue press 'y'!\n");
  error=getch();
  if((error!='y') && (error!='Y'))
  { fprintf(stderr,"aborted...\n"); exit(-1); }
  
  init_lcd(port_addr);

  /* Erase memory */
  outportb(port_addr+1,0x46); /* CSRW command (set cursor position) */
  outportb(port_addr  ,   0);
  outportb(port_addr  ,   0);
  outportb(port_addr+1,0x4C); /* Cursor movement right (CSRDIR command) */
  outportb(port_addr+1,0x42); /* MWRITE command */
  for(cnt=0; cnt<32768; cnt++)
    outportb(port_addr, 0x55);

  /* Copy text layer to display memory */
  outportb(port_addr+1,0x46); /* CSRW command (set cursor position) */
  outportb(port_addr  ,   0); /* Layer 1 starts at 0000H */
  outportb(port_addr  ,   0);
  outportb(port_addr+1,0x4C); /* Cursor movement right (CSRDIR command) */
  outportb(port_addr+1,0x42); /* MWRITE command */
  for(cnt=0; cnt<WINHEIGHT/8; cnt++)
  {
    for(cnt2=0; cnt2<WINWIDTH/8; cnt2++)
    {
      outportb(port_addr, txt_scr[cnt*WINWIDTH/8+cnt2]);
      printf("%c",txt_scr[cnt*WINWIDTH/8+cnt2]);
    }
    printf("\n");
  }
  printf("\n");
  printf("Press a key to update LCD display; press 'q' to quit!\n");
  a=0;

  do
  {
    clear_window();
    writetext("Grpahics layer",screen,
              0,0,WINWIDTH,WINHEIGHT,NULL,NULL);
    writetext("Your LCD works!",screen,
              0,18,WINWIDTH,WINHEIGHT,NULL,NULL);
    for(b=a;b<a+LINES;b++)
      draw_line(sin( b*STEP/180   *M_PI) * 8 * RAD + CENTERX,
                cos( b*STEP/180   *M_PI) *     RAD + CENTERY,
                sin((b*STEP/180+1)*M_PI) * 8 * RAD + CENTERX,
                cos((b*STEP/180+1)*M_PI) *     RAD + CENTERY, screen);
    a++;

    /* Copy graphics layer to display memory */
    outportb(port_addr+1,0x46); /* CSRW command (set cursor position) */
    outportb(port_addr  ,   0); /* Layer 2 starts at 1000H */
    outportb(port_addr  ,0x10);
    outportb(port_addr+1,0x4C); /* Cursor movement right (CSRDIR command) */
    outportb(port_addr+1,0x42); /* MWRITE command */
    for(cnt=0; cnt<(WINWIDTH*WINHEIGHT/8); cnt++)
    {
      if(timetest)
      {
        if(cnt%2)
        {
          outportb(port_addr,   0xff);
          outportb(port_addr2,  0xff);
          outportb(port_addr2,  0xff);
        }
        else
        {
          outportb(port_addr,   0);
          outportb(port_addr2,  0);
          outportb(port_addr2,  0);
        }
      }
      else
      {
        outportb(port_addr  , screen[cnt]);
        if(probe)
        {
          outportb(port_addr2,  screen[cnt]);
          outportb(port_addr2,  screen[cnt]);
        }
      }
    }

    printf("%d\r",(int)a); fflush(stdout);
  }
  while(getch() != 'q');

  outportb(port_addr+1,0x58); /* Display OFF */
}

/* And here we are initialise the LCD */
/* Check SED1330 documentation for more information! */
void init_lcd(int port_addr)
{
  outportb(port_addr+1,0x40); /* INIT command */
  outportb(port_addr  ,0x30); /* PRT=0, IV=1, W/S=0, M0-M2 */
  outportb(port_addr  ,0x07); /* WF=0 (16-line AC drive), FX=7 */
  outportb(port_addr  ,0x07); /* FY=7 */
  outportb(port_addr  ,  63); /* C/R = 64 - 1, where 64 = 512/8 */
  outportb(port_addr  ,  67); /* Offset to next line. => 172.3 Hz
                             refresh @ 6MHz osc. */
  outportb(port_addr  ,  64); /* 63, because W/S=0 */
  outportb(port_addr  ,  64); /* APL (C/R+1 LOWER) */
  outportb(port_addr  ,   0); /* APH (C/R+1 UPPER) */

  outportb(port_addr+1,0x44); /* SCROLL command */
  outportb(port_addr  ,   0); /* Layer 1 start address to 0000H */
  outportb(port_addr  ,   0);
  outportb(port_addr  ,  64); /* Display 64 lines               */
  outportb(port_addr  ,   0); /* Layer 2 start address to 1000H */
  outportb(port_addr  ,0x10);
  outportb(port_addr  ,  64); /* Display 64 lines               */

  outportb(port_addr+1,0x5A); /* HDOT SCR command */
  outportb(port_addr  ,   0); /* 0 for no scroll offset */

  outportb(port_addr+1,0x5B); /* OVERLAY command */
  outportb(port_addr  ,0x01); /* 2 layers, OV=0, 1-Text, 2-Graph */

  outportb(port_addr+1,0x59); /* DISPLAY ON/OFF command */
  outportb(port_addr  ,0x18); /* 0x14: SCREEN 1,2 On, no cursor... */
                          /* 0x18: SCREEN 1 (with flash),2 On, no cursor... */
}

/* command line argument parsing. read in a hexadecimal number */
unsigned char get_hexaarg(char *str, int *pos, int *val)
{
  unsigned char firstchar=1, value=1;

  if(str[*pos]!='0') return(2);
  if((str[(*pos)+1]!='x') && (str[(*pos)+1]!='X')) return(3);
  (*pos)+=2;
  while(value)
  {
    switch(str[*pos])
    {
      case '0' ... '9': if(firstchar) { *val=0; firstchar=0; }
                        *val<<=4; *val+=str[(*pos)++]-'0'; break;
      case 'a' ... 'f': if(firstchar) { *val=0; firstchar=0; }
                        *val<<=4; *val+=str[(*pos)++]-'a'+10; break;
      case 'A' ... 'F': if(firstchar) { *val=0; firstchar=0; }
                        *val<<=4; *val+=str[(*pos)++]-'A'+10; break;
      default: value=0; break;
    }
  }
  return(0);
}

/* This function writes text to the graphics layer. This is an extra, I didn't
   comment it... */
int writetext(unsigned char*szoveg, char*screen, int startx, int starty,
              int stopx, int stopy, int* return_x, int* return_y)
{
  unsigned long int a;
  int pos_in_txt, cur_x, cur_y, chr_sx, chr_sy, chr_ss, y, puf_sl;
  unsigned char chr;   
  int size_of_long_int;
  
  size_of_long_int=sizeof(a)*8;
  if(size_of_long_int<24)
  {
    fprintf(stderr,"Check writetext() in display.c because your compiler handles "
                   "long int less than 24 bits. Try to use a bigger type!\n");
    return 0;
  }
  chr_sx=charset_10x18[0]; chr_sy=charset_10x18[1];
  chr_ss=(chr_sx-1)/8+1;
  pos_in_txt=0; cur_x=startx; cur_y=starty;
  while((chr=szoveg[pos_in_txt++])!=0)
  {
    if(chr == '\n')
    {
      cur_x=startx; cur_y+=chr_sy;
    }
    else
    {
      if(cur_y+chr_sy<=stopy)
      {
        if(chr_ss == 1 && (cur_x+chr_sx)<=stopx)
        {
          puf_sl=16-chr_sx-(cur_x%8);
          for(y=0;y<chr_sy;y++)   
          {
            a=charset_10x18[(chr+1)*chr_sy+y]<<puf_sl;
            screen[(cur_x+(cur_y+y)*WINWIDTH)/8  ]|= a>>8;
            screen[(cur_x+(cur_y+y)*WINWIDTH)/8+1]|= a;
          }
          cur_x+=chr_sx;
        }
        else
          if(chr_ss == 2 && (cur_x+chr_sx)<=stopx)
          {
            puf_sl=24-chr_sx-(cur_x%8);
            for(y=0;y<chr_sy;y++)
            {
              a=((charset_10x18[((chr+1)*chr_sy+y)*2  ]) * 256 +
                  charset_10x18[((chr+1)*chr_sy+y)*2+1]          ) << puf_sl;
              screen[(cur_x+(cur_y+y)*WINWIDTH)/8  ]|= a>>16;
              screen[(cur_x+(cur_y+y)*WINWIDTH)/8+1]|= a>>8;
              screen[(cur_x+(cur_y+y)*WINWIDTH)/8+2]|= a;
            }
            cur_x+=chr_sx;
          }
      }
    }
  }
  if(return_x != NULL) return_x[0]=cur_x;
  if(return_y != NULL) return_y[0]=cur_y;
  return 1;
}

/* This one clears the window (in the PC's memory!) */
void clear_window()
{
  long int x;
  for(x=0;x<WINWIDTH*WINHEIGHT/8;x++)            /* Clear data   */
    screen[x]=0;
}

/* Draw one line. Another extra. */
void draw_line(int startx, int starty, int stopx, int stopy, unsigned char* scr)
{
  int a,b,c,d;

  c=stopx-startx; d=stopy-starty;

  if(c*c>d*d)
  {
    if(c<0)
      for(a=0;a>=c;a--)
      {
        b=(float) (d)/(float)(c)*(float)a+(float)0.5 + starty;
        screen[b*WINWIDTH/8+(startx+a)/8] |= 1 << (7-(startx+a)%8);
      }
    else
      for(a=0;a<=c;a++)
      {
        b=(float) (d)/(float)(c)*(float)a+(float)0.5 + starty;
        screen[b*WINWIDTH/8+(startx+a)/8] |= 1 << (7-(startx+a)%8);
      }
  }
  else
  {
    if(d<0)
      for(a=0;a>=d;a--)
      {
        b=(float) (c)/(float)(d)*(float)a+(float)0.5 + startx;
        screen[(starty+a)*WINWIDTH/8+b/8] |= 1 << (7-b%8);
      }
    else
      for(a=0;a<=d;a++)
      {
        b=(float) (c)/(float)(d)*(float)a+(float)0.5 + startx;
        screen[(starty+a)*WINWIDTH/8+b/8] |= 1 << (7-b%8);
      }
  }
}

/* The charset */
unsigned char charset_10x18[257*36]=
   {10,   18, 0,    0, 0,    0, 0,    0, 0,    0, 0,    0, 0,    0, 0,    0, 0,    0, 0,    0, 0,    0, 0,    0, 0,    0, 0,    0, 0,    0, 0,    0, 0,    0, 0,    0,
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 0 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0x84, 1, 0x02, 1, 0x02, 1, 0x02, 1, 0x4a, 1, 0x02, 1, 0x02, 1, 0x4a, 1, 0x32, 1, 0x02, 1, 0x02, 0, 0x84, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 1 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0xfc, 1, 0xfe, 1, 0xfe, 1, 0xfe, 1, 0xb6, 1, 0xfe, 1, 0xfe, 1, 0xb6, 1, 0xce, 1, 0xfe, 1, 0xfe, 0, 0xfc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 2 */
     0, 0x00, 0, 0x00, 0, 0xcc, 1, 0xfe, 1, 0xfe, 1, 0xfe, 1, 0xfe, 1, 0xfe, 1, 0xfe, 0, 0xfc, 0, 0xfc, 0, 0xfc, 0, 0x78, 0, 0x78, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 3 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x78, 0, 0x78, 0, 0xfc, 0, 0xfc, 1, 0xfe, 1, 0xfe, 0, 0xfc, 0, 0xfc, 0, 0x78, 0, 0x78, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 4 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x78, 0, 0x78, 0, 0x78, 0, 0x30, 0, 0xcc, 1, 0xfe, 1, 0xfe, 0, 0xcc, 0, 0x30, 0, 0x30, 0, 0x78, 0, 0x78, 0, 0xfc, 0, 0x00, 0, 0x00, /* Char 5 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x78, 0, 0x78, 0, 0xfc, 1, 0xfe, 1, 0xfe, 1, 0xfe, 1, 0xfe, 0, 0xb4, 0, 0x30, 0, 0x78, 0, 0x78, 0, 0xfc, 0, 0x00, 0, 0x00, /* Char 6 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x30, 0, 0x78, 0, 0x78, 0, 0x30, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 7 */
     3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xcf, 3, 0x87, 3, 0x87, 3, 0xcf, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, /* Char 8 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 9 */
     3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0x87, 3, 0x33, 3, 0x7b, 3, 0x7b, 3, 0x33, 3, 0x87, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, /* Char 10 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x0f, 0, 0x03, 0, 0x07, 0, 0x0d, 0, 0x19, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 11 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x30, 0, 0x30, 0, 0xfc, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 12 */
     0, 0x00, 0, 0x00, 0, 0x10, 0, 0x10, 0, 0x1c, 0, 0x1c, 0, 0x1c, 0, 0x1e, 0, 0x12, 0, 0x12, 0, 0x12, 0, 0x10, 0, 0x30, 0, 0x70, 0, 0x70, 0, 0x60, 0, 0x00, 0, 0x00, /* Char 13 */
     0, 0x00, 0, 0x00, 0, 0x02, 0, 0x06, 0, 0x1e, 0, 0x72, 0, 0x66, 0, 0x4e, 0, 0x5a, 0, 0x72, 0, 0x46, 0, 0x4e, 0, 0xce, 1, 0xcc, 1, 0xc0, 1, 0x80, 0, 0x00, 0, 0x00, /* Char 14 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x10, 0, 0x92, 0, 0x7c, 0, 0x44, 0, 0x82, 0, 0x44, 0, 0x7c, 0, 0x92, 0, 0x10, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 15 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0x80, 1, 0xe0, 1, 0xf8, 1, 0xfe, 1, 0xf8, 1, 0xe0, 1, 0x80, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 16 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x06, 0, 0x1e, 0, 0x7e, 1, 0xfe, 0, 0x7e, 0, 0x1e, 0, 0x06, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 17 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x78, 0, 0xfc, 0, 0xb4, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0xb4, 0, 0xfc, 0, 0x78, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 18 */
     0, 0x00, 0, 0x00, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0x00, 0, 0x00, 0, 0xcc, 0, 0xcc, 0, 0x00, 0, 0x00, /* Char 19 */
     0, 0x00, 0, 0x00, 0, 0xfe, 1, 0xe6, 1, 0xe6, 1, 0xe6, 1, 0xe6, 1, 0xe6, 1, 0xe6, 0, 0xe6, 0, 0x66, 0, 0x66, 0, 0x66, 0, 0x66, 0, 0x66, 0, 0x66, 0, 0x00, 0, 0x00, /* Char 20 */
     0, 0x00, 0, 0x00, 0, 0xfc, 1, 0x86, 1, 0xc6, 0, 0xe0, 0, 0x70, 0, 0xd8, 0, 0xcc, 0, 0x6c, 0, 0x38, 0, 0x1c, 0, 0x0e, 1, 0x86, 1, 0x86, 0, 0xfc, 0, 0x00, 0, 0x00, /* Char 21 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0xfe, 1, 0xfe, 1, 0xfe, 1, 0xfe, 0, 0x00, 0, 0x00, /* Char 22 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x78, 0, 0xfc, 0, 0xfc, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0xfc, 0, 0xfc, 0, 0x78, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 23 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x78, 0, 0xfc, 0, 0xfc, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 24 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0xfc, 0, 0xfc, 0, 0x78, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 25 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x18, 0, 0x1c, 1, 0xfe, 1, 0xfe, 0, 0x1c, 0, 0x18, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 26 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x60, 0, 0xe0, 1, 0xfe, 1, 0xfe, 0, 0xe0, 0, 0x60, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 27 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0x80, 1, 0x80, 1, 0xfc, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 28 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x48, 0, 0xcc, 1, 0xfe, 1, 0xfe, 0, 0xcc, 0, 0x48, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 29 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x78, 0, 0x78, 0, 0xfc, 0, 0xfc, 1, 0xfe, 1, 0xfe, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 30 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0xfe, 1, 0xfe, 0, 0xfc, 0, 0xfc, 0, 0x78, 0, 0x78, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 31 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 32 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x78, 0, 0x78, 0, 0x78, 0, 0x78, 0, 0x78, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 33 */
     0, 0x00, 0, 0x00, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 34 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 1, 0xfe, 0, 0xcc, 0, 0xcc, 1, 0xfe, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 35 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0xfc, 1, 0xb6, 1, 0xb6, 1, 0xf0, 0, 0x70, 0, 0x38, 0, 0x3e, 1, 0xb6, 1, 0xb6, 0, 0xfc, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 36 */
     0, 0x00, 0, 0x00, 0, 0x86, 1, 0xc4, 1, 0x4c, 1, 0x48, 1, 0xd8, 0, 0x90, 0, 0x30, 0, 0x20, 0, 0x64, 0, 0x4e, 0, 0xca, 0, 0x8a, 1, 0x8e, 1, 0x04, 0, 0x00, 0, 0x00, /* Char 37 */
     0, 0x00, 0, 0x00, 0, 0xf0, 1, 0x98, 1, 0x08, 1, 0x08, 1, 0x98, 0, 0xf0, 0, 0x60, 0, 0xf2, 1, 0x9e, 1, 0x0c, 1, 0x08, 1, 0x0c, 1, 0x9e, 0, 0xf2, 0, 0x00, 0, 0x00, /* Char 38 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x10, 0, 0x20, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 39 */
     0, 0x00, 0, 0x18, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x18, 0, 0x00, /* Char 40 */
     0, 0x00, 0, 0x60, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x60, 0, 0x00, /* Char 41 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0xcc, 0, 0x78, 1, 0xfe, 0, 0x78, 0, 0xcc, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 42 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 1, 0xfe, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 43 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x10, 0, 0x20, /* Char 44 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0xfe, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 45 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 46 */
     0, 0x00, 0, 0x00, 0, 0x06, 0, 0x06, 0, 0x0c, 0, 0x0c, 0, 0x18, 0, 0x18, 0, 0x30, 0, 0x30, 0, 0x60, 0, 0x60, 0, 0xc0, 0, 0xc0, 1, 0x80, 1, 0x80, 0, 0x00, 0, 0x00, /* Char 47 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x8e, 1, 0x8e, 1, 0x96, 1, 0x96, 1, 0xa6, 1, 0xa6, 1, 0xc6, 1, 0xc6, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 48 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x70, 1, 0xf0, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 1, 0xfe, 0, 0x00, 0, 0x00, /* Char 49 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 0, 0x06, 0, 0x06, 0, 0x0c, 0, 0x18, 0, 0x30, 0, 0x60, 0, 0xc0, 1, 0x80, 1, 0x80, 1, 0xfe, 0, 0x00, 0, 0x00, /* Char 50 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 0, 0x06, 0, 0x06, 0, 0x7c, 0, 0x06, 0, 0x06, 0, 0x06, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 51 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0xc0, 0, 0xc0, 0, 0xd8, 1, 0x98, 1, 0x98, 1, 0x98, 1, 0xfe, 0, 0x18, 0, 0x18, 0, 0x00, 0, 0x00, /* Char 52 */
     0, 0x00, 0, 0x00, 1, 0xfe, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0xf8, 0, 0x0c, 0, 0x06, 0, 0x06, 0, 0x06, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 53 */
     0, 0x00, 0, 0x00, 0, 0x1e, 0, 0x30, 0, 0x60, 0, 0xc0, 0, 0xc0, 1, 0x80, 1, 0xf8, 1, 0x8c, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 54 */
     0, 0x00, 0, 0x00, 1, 0xfe, 0, 0x06, 0, 0x06, 0, 0x06, 0, 0x0c, 0, 0x0c, 0, 0x0c, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 55 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 56 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xc6, 0, 0x7e, 0, 0x06, 0, 0x0c, 0, 0x0c, 0, 0x18, 0, 0x30, 1, 0xe0, 0, 0x00, 0, 0x00, /* Char 57 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 58 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x10, 0, 0x20, /* Char 59 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x0c, 0, 0x18, 0, 0x30, 0, 0x60, 0, 0xc0, 1, 0x80, 0, 0xc0, 0, 0x60, 0, 0x30, 0, 0x18, 0, 0x0c, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 60 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0xfe, 0, 0x00, 0, 0x00, 1, 0xfe, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 61 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0x80, 0, 0xc0, 0, 0x60, 0, 0x30, 0, 0x18, 0, 0x0c, 0, 0x18, 0, 0x30, 0, 0x60, 0, 0xc0, 1, 0x80, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 62 */
     0, 0x00, 0, 0x00, 0, 0xfc, 1, 0xce, 1, 0x86, 0, 0x06, 0, 0x0e, 0, 0x0c, 0, 0x18, 0, 0x18, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 63 */
     0, 0x00, 0, 0x00, 0, 0x7c, 0, 0xc6, 1, 0x83, 1, 0x83, 1, 0x9f, 1, 0xb3, 1, 0xb3, 1, 0xb3, 1, 0xb7, 1, 0x9b, 1, 0x80, 1, 0x80, 0, 0xc3, 0, 0x7e, 0, 0x00, 0, 0x00, /* Char 64 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0xfe, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0x00, 0, 0x00, /* Char 65 */
     0, 0x00, 0, 0x00, 1, 0xf8, 1, 0x8c, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x8c, 1, 0xf8, 1, 0x8c, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x8c, 1, 0xf8, 0, 0x00, 0, 0x00, /* Char 66 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 67 */
     0, 0x00, 0, 0x00, 1, 0xf8, 1, 0x8c, 1, 0x8c, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x8c, 1, 0x8c, 1, 0xf8, 0, 0x00, 0, 0x00, /* Char 68 */
     0, 0x00, 0, 0x00, 1, 0xfe, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0xfc, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0xfe, 0, 0x00, 0, 0x00, /* Char 69 */
     0, 0x00, 0, 0x00, 1, 0xfe, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0xfc, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 0, 0x00, 0, 0x00, /* Char 70 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x9e, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 71 */
     0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0xfe, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0x00, 0, 0x00, /* Char 72 */
     0, 0x00, 0, 0x00, 1, 0xfe, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 1, 0xfe, 0, 0x00, 0, 0x00, /* Char 73 */
     0, 0x00, 0, 0x00, 0, 0x06, 0, 0x06, 0, 0x06, 0, 0x06, 0, 0x06, 0, 0x06, 0, 0x06, 0, 0x06, 0, 0x06, 0, 0x06, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 74 */
     0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 1, 0x8c, 1, 0x9c, 1, 0x98, 1, 0xb0, 1, 0xe0, 1, 0xe0, 1, 0xb0, 1, 0x98, 1, 0x9c, 1, 0x8c, 1, 0x86, 1, 0x86, 0, 0x00, 0, 0x00, /* Char 75 */
     0, 0x00, 0, 0x00, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0xfe, 0, 0x00, 0, 0x00, /* Char 76 */
     0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0xce, 1, 0xce, 1, 0xce, 1, 0xfe, 1, 0xb6, 1, 0xb6, 1, 0xb6, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0x00, 0, 0x00, /* Char 77 */
     0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 1, 0xc6, 1, 0xc6, 1, 0xe6, 1, 0xa6, 1, 0xb6, 1, 0x96, 1, 0x9e, 1, 0x8e, 1, 0x8e, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0x00, 0, 0x00, /* Char 78 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 79 */
     0, 0x00, 0, 0x00, 1, 0xf8, 1, 0x8c, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x8c, 1, 0xf8, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 0, 0x00, 0, 0x00, /* Char 80 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x18, 0, 0x0c, /* Char 81 */
     0, 0x00, 0, 0x00, 1, 0xf8, 1, 0x8c, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x8c, 1, 0xf8, 1, 0x98, 1, 0x8c, 1, 0x8c, 1, 0x8c, 1, 0x8c, 1, 0x86, 0, 0x00, 0, 0x00, /* Char 82 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x80, 1, 0xe0, 0, 0xf0, 0, 0x3c, 0, 0x1e, 0, 0x06, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 83 */
     0, 0x00, 0, 0x00, 1, 0xfe, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 84 */
     0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 85 */
     0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0x48, 0, 0x78, 0, 0x78, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 86 */
     0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0xb6, 1, 0xb6, 1, 0xb6, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0x00, 0, 0x00, /* Char 87 */
     0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0xcc, 0, 0x78, 0, 0x78, 0, 0xcc, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0x00, 0, 0x00, /* Char 88 */
     0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0xfc, 0, 0x78, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 89 */
     0, 0x00, 0, 0x00, 1, 0xfe, 0, 0x06, 0, 0x06, 0, 0x0c, 0, 0x0c, 0, 0x18, 0, 0x30, 0, 0x60, 0, 0x60, 0, 0xc0, 0, 0xc0, 1, 0x80, 1, 0x80, 1, 0xfe, 0, 0x00, 0, 0x00, /* Char 90 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 91 */
     0, 0x00, 0, 0x00, 1, 0x80, 1, 0x80, 0, 0xc0, 0, 0xc0, 0, 0x60, 0, 0x60, 0, 0x30, 0, 0x30, 0, 0x18, 0, 0x18, 0, 0x0c, 0, 0x0c, 0, 0x06, 0, 0x06, 0, 0x00, 0, 0x00, /* Char 92 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 93 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x7c, 1, 0xce, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 94 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 3, 0xff, /* Char 95 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x20, 0, 0x10, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 96 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x7c, 0, 0x86, 0, 0x06, 0, 0xfe, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x8e, 0, 0xf6, 0, 0x00, 0, 0x00, /* Char 97 */
     0, 0x00, 0, 0x00, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0xb8, 1, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0xcc, 1, 0xb8, 0, 0x00, 0, 0x00, /* Char 98 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x7c, 0, 0xc6, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 0, 0xc6, 0, 0x7c, 0, 0x00, 0, 0x00, /* Char 99 */
     0, 0x00, 0, 0x00, 0, 0x06, 0, 0x06, 0, 0x06, 0, 0x06, 0, 0x06, 0, 0x76, 0, 0xce, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xce, 0, 0x76, 0, 0x00, 0, 0x00, /* Char 100 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0xfe, 1, 0x80, 1, 0x80, 0, 0xc6, 0, 0x7c, 0, 0x00, 0, 0x00, /* Char 101 */
     0, 0x00, 0, 0x00, 0, 0x3c, 0, 0x66, 0, 0x60, 0, 0x60, 0, 0x60, 1, 0xfc, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x60, 0, 0x00, 0, 0x00, /* Char 102 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x76, 0, 0xce, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xce, 0, 0x76, 0, 0x06, 1, 0xcc, 0, 0x78, /* Char 103 */
     0, 0x00, 0, 0x00, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0xb8, 1, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0x00, 0, 0x00, /* Char 104 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0xf0, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0xfc, 0, 0x00, 0, 0x00, /* Char 105 */
     0, 0x00, 0, 0x00, 0, 0x18, 0, 0x18, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x78, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0xd8, 0, 0x70, /* Char 106 */
     0, 0x00, 0, 0x00, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x86, 1, 0x8c, 1, 0x98, 1, 0xb0, 1, 0xe0, 1, 0xf0, 1, 0x98, 1, 0x8c, 1, 0x86, 0, 0x00, 0, 0x00, /* Char 107 */
     0, 0x00, 0, 0x00, 0, 0xf0, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0xfc, 0, 0x00, 0, 0x00, /* Char 108 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0xcc, 1, 0xfe, 1, 0xb6, 1, 0xb6, 1, 0xb6, 1, 0xb6, 1, 0xb6, 1, 0xb6, 1, 0x86, 0, 0x00, 0, 0x00, /* Char 109 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0xb8, 1, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0x00, 0, 0x00, /* Char 110 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 111 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0xb8, 1, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0xcc, 1, 0xb8, 1, 0x80, 1, 0x80, /* Char 112 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x76, 0, 0x8e, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0x8e, 0, 0x76, 0, 0x06, 0, 0x06, /* Char 113 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0x9c, 1, 0xfe, 1, 0xc0, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 0, 0x00, 0, 0x00, /* Char 114 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0xfc, 1, 0x86, 1, 0x80, 0, 0xe0, 0, 0x30, 0, 0x1c, 0, 0x06, 1, 0x86, 0, 0xfc, 0, 0x00, 0, 0x00, /* Char 115 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0xfc, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x1c, 0, 0x00, 0, 0x00, /* Char 116 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x8e, 0, 0xf6, 0, 0x00, 0, 0x00, /* Char 117 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x48, 0, 0x78, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 118 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0x86, 1, 0xb6, 1, 0xb6, 1, 0xb6, 1, 0xb6, 1, 0xb6, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0x00, 0, 0x00, /* Char 119 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0xfc, 0, 0x30, 0, 0xfc, 0, 0xcc, 1, 0x86, 1, 0x86, 0, 0x00, 0, 0x00, /* Char 120 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0xcc, 0, 0x78, 0, 0x30, 0, 0x60, 1, 0xc0, /* Char 121 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0xfe, 0, 0x06, 0, 0x0c, 0, 0x18, 0, 0x30, 0, 0x60, 0, 0xc0, 1, 0x80, 1, 0xfe, 0, 0x00, 0, 0x00, /* Char 122 */
     0, 0x00, 0, 0x00, 0, 0x1c, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x60, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x1c, 0, 0x00, /* Char 123 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, /* Char 124 */
     0, 0x00, 0, 0x00, 0, 0xe0, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x18, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0xe0, 0, 0x00, /* Char 125 */
     0, 0x00, 0, 0x00, 0, 0x66, 1, 0x98, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 126 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x78, 0, 0xcc, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0xfe, 1, 0xfe, 0, 0x00, 0, 0x00, /* Char 127 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x18, 0, 0x30, /* Char 128 */
     0, 0x00, 0, 0x00, 0, 0xcc, 0, 0xcc, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x8e, 0, 0xf6, 0, 0x00, 0, 0x00, /* Char 129 */
     0, 0x00, 0, 0x00, 0, 0x0e, 0, 0x18, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0xfe, 1, 0x80, 1, 0x80, 0, 0xc6, 0, 0x7c, 0, 0x00, 0, 0x00, /* Char 130 */
     0, 0x00, 0, 0x00, 0, 0x18, 0, 0x3c, 0, 0x66, 0, 0x00, 0, 0x00, 0, 0x7c, 0, 0x86, 0, 0x06, 0, 0xfe, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x8e, 0, 0xf6, 0, 0x00, 0, 0x00, /* Char 131 */
     0, 0x00, 0, 0x00, 0, 0xcc, 0, 0xcc, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x7c, 0, 0x86, 0, 0x06, 0, 0xfe, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x8e, 0, 0xf6, 0, 0x00, 0, 0x00, /* Char 132 */
     0, 0x00, 0, 0x00, 0, 0x70, 0, 0x18, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x7c, 0, 0x86, 0, 0x06, 0, 0xfe, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x8e, 0, 0xf6, 0, 0x00, 0, 0x00, /* Char 133 */
     0, 0x00, 0, 0x00, 0, 0x38, 0, 0x6c, 0, 0x38, 0, 0x00, 0, 0x00, 0, 0x7c, 0, 0x86, 0, 0x06, 0, 0xfe, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x8e, 0, 0xf6, 0, 0x00, 0, 0x00, /* Char 134 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x7c, 0, 0xc6, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 0, 0xc6, 0, 0x7c, 0, 0x18, 0, 0x30, /* Char 135 */
     0, 0x00, 0, 0x00, 0, 0x10, 0, 0x38, 0, 0x6c, 0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0xfe, 1, 0x80, 1, 0x80, 0, 0xc6, 0, 0x7c, 0, 0x00, 0, 0x00, /* Char 136 */
     0, 0x00, 0, 0x00, 0, 0xcc, 0, 0xcc, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0xfe, 1, 0x80, 1, 0x80, 0, 0xc6, 0, 0x7c, 0, 0x00, 0, 0x00, /* Char 137 */
     0, 0x00, 0, 0x00, 0, 0x70, 0, 0x18, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0xfe, 1, 0x80, 1, 0x80, 0, 0xc6, 0, 0x7c, 0, 0x00, 0, 0x00, /* Char 138 */
     0, 0x00, 0, 0x00, 0, 0xcc, 0, 0xcc, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0xf0, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0xfc, 0, 0x00, 0, 0x00, /* Char 139 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x78, 0, 0xcc, 0, 0x00, 0, 0x00, 0, 0xf0, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0xfc, 0, 0x00, 0, 0x00, /* Char 140 */
     0, 0x00, 0, 0x00, 0, 0xe0, 0, 0x30, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0xf0, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0xfc, 0, 0x00, 0, 0x00, /* Char 141 */
     0, 0x00, 0, 0x00, 0, 0xcc, 0, 0xcc, 0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0xfe, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0x00, 0, 0x00, /* Char 142 */
     0, 0x00, 0, 0x10, 0, 0x28, 0, 0x28, 0, 0x10, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0xfe, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0x00, 0, 0x00, /* Char 143 */
     0, 0x00, 0, 0x00, 0, 0x0e, 0, 0x18, 0, 0x00, 0, 0x00, 1, 0xfe, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0xfc, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0x80, 1, 0xfe, 0, 0x00, 0, 0x00, /* Char 144 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0xdc, 1, 0x36, 0, 0x36, 0, 0xf6, 1, 0xbe, 1, 0xb0, 1, 0xb0, 1, 0xb2, 0, 0xec, 0, 0x00, 0, 0x00, /* Char 145 */
     0, 0x00, 0, 0x00, 0, 0x3e, 0, 0x70, 0, 0xf0, 1, 0xf0, 1, 0xb0, 1, 0xb0, 1, 0xb0, 1, 0xbc, 1, 0xf0, 1, 0xb0, 1, 0xb0, 1, 0xb0, 1, 0xb0, 1, 0xbe, 0, 0x00, 0, 0x00, /* Char 146 */
     0, 0x00, 0, 0x00, 0, 0x10, 0, 0x38, 0, 0x6c, 0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 147 */
     0, 0x00, 0, 0x00, 0, 0xcc, 0, 0xcc, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 148 */
     0, 0x00, 0, 0x00, 0, 0xe0, 0, 0x30, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 149 */
     0, 0x00, 0, 0x00, 0, 0x10, 0, 0x38, 0, 0x6c, 0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x8e, 0, 0xf6, 0, 0x00, 0, 0x00, /* Char 150 */
     0, 0x00, 0, 0x00, 0, 0xe0, 0, 0x30, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x8e, 0, 0xf6, 0, 0x00, 0, 0x00, /* Char 151 */
     0, 0x00, 0, 0x00, 0, 0xcc, 0, 0xcc, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0xfc, 0, 0x38, 0, 0x30, 0, 0x60, 1, 0xc0, /* Char 152 */
     0, 0x00, 0, 0x00, 0, 0xcc, 0, 0xcc, 0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 153 */
     0, 0x00, 0, 0x00, 0, 0xcc, 0, 0xcc, 0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 154 */
     0, 0x00, 0, 0x00, 0, 0x10, 0, 0x10, 0, 0x7c, 0, 0xd6, 0, 0xd6, 0, 0xd0, 0, 0xd0, 0, 0xd0, 0, 0xd6, 0, 0xd6, 0, 0x7c, 0, 0x10, 0, 0x10, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 155 */
     0, 0x00, 0, 0x00, 0, 0x7c, 0, 0xc6, 1, 0x80, 1, 0x80, 1, 0x80, 0, 0xc0, 0, 0xc0, 1, 0xf8, 0, 0xc0, 0, 0xc0, 0, 0xc0, 0, 0xc0, 1, 0x86, 1, 0xfc, 0, 0x00, 0, 0x00, /* Char 156 */
     0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0x78, 0, 0x78, 0, 0x30, 0, 0xfc, 0, 0x30, 0, 0xfc, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 157 */
     0, 0x00, 0, 0x00, 1, 0xe0, 1, 0xb0, 1, 0xb0, 1, 0xb0, 1, 0xb0, 1, 0xb0, 1, 0xec, 1, 0x8c, 1, 0x9e, 1, 0x8c, 1, 0x8c, 1, 0x8c, 1, 0x8c, 1, 0x86, 0, 0x00, 0, 0x00, /* Char 158 */
     0, 0x00, 0, 0x00, 0, 0x1c, 0, 0x32, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0xfc, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 1, 0x30, 0, 0xe0, /* Char 159 */
     0, 0x00, 0, 0x00, 0, 0x0e, 0, 0x18, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x7c, 0, 0x86, 0, 0x06, 0, 0xfe, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x8e, 0, 0xf6, 0, 0x00, 0, 0x00, /* Char 160 */
     0, 0x00, 0, 0x00, 0, 0x1c, 0, 0x30, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0xf0, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0xf8, 0, 0x00, 0, 0x00, /* Char 161 */
     0, 0x00, 0, 0x00, 0, 0x0e, 0, 0x18, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 162 */
     0, 0x00, 0, 0x00, 0, 0x1c, 0, 0x30, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x8e, 0, 0xf6, 0, 0x00, 0, 0x00, /* Char 163 */
     0, 0x00, 0, 0x00, 0, 0x34, 0, 0x58, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0xb8, 1, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0x00, 0, 0x00, /* Char 164 */
     0, 0x00, 0, 0x00, 0, 0x34, 0, 0x58, 0, 0x00, 0, 0x00, 1, 0x86, 1, 0xc6, 1, 0xe6, 1, 0xb6, 1, 0x9e, 1, 0x8e, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0x00, 0, 0x00, /* Char 165 */
     0, 0x00, 0, 0x00, 0, 0x7c, 0, 0x06, 0, 0x7e, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0x7e, 0, 0x00, 1, 0xfe, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 166 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0xcc, 0, 0x78, 0, 0x00, 1, 0xfe, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 167 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x60, 0, 0x60, 0, 0xc0, 1, 0xc0, 1, 0x80, 1, 0x86, 1, 0xce, 0, 0xfc, 0, 0x00, 0, 0x00, /* Char 168 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0xfc, 0, 0xc0, 0, 0xc0, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 169 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0xfc, 0, 0x0c, 0, 0x0c, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 170 */
     0, 0x00, 0, 0x82, 1, 0x82, 0, 0x84, 0, 0x84, 0, 0x88, 0, 0x88, 1, 0xd0, 0, 0x10, 0, 0x20, 0, 0x2c, 0, 0x52, 0, 0x42, 0, 0x84, 0, 0x88, 1, 0x10, 1, 0x1e, 0, 0x00, /* Char 171 */
     0, 0x00, 0, 0x82, 1, 0x82, 0, 0x84, 0, 0x84, 0, 0x88, 0, 0x88, 1, 0xd0, 0, 0x10, 0, 0x20, 0, 0x24, 0, 0x48, 0, 0x48, 0, 0x94, 0, 0x9e, 1, 0x04, 1, 0x04, 0, 0x00, /* Char 172 */
     0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x78, 0, 0x78, 0, 0x78, 0, 0x78, 0, 0x78, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 173 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x22, 0, 0x66, 0, 0xcc, 1, 0x98, 1, 0x98, 0, 0xcc, 0, 0x66, 0, 0x22, 0, 0x00, 0, 0x00, /* Char 174 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0x10, 1, 0x98, 0, 0xcc, 0, 0x66, 0, 0x66, 0, 0xcc, 1, 0x98, 1, 0x10, 0, 0x00, 0, 0x00, /* Char 175 */
     0, 0x00, 0, 0x84, 0, 0x00, 2, 0x10, 0, 0x00, 0, 0x00, 0, 0x84, 0, 0x00, 2, 0x10, 0, 0x00, 0, 0x84, 0, 0x00, 2, 0x10, 0, 0x00, 0, 0x00, 0, 0x84, 0, 0x00, 2, 0x10, /* Char 176 */
     0, 0x42, 2, 0x10, 0, 0x42, 2, 0x10, 0, 0x42, 2, 0x10, 0, 0x42, 2, 0x10, 0, 0x42, 2, 0x10, 0, 0x42, 2, 0x10, 0, 0x42, 2, 0x10, 0, 0x42, 2, 0x10, 0, 0x42, 2, 0x10, /* Char 177 */
     2, 0xaa, 1, 0x55, 2, 0xaa, 1, 0x55, 2, 0xaa, 1, 0x55, 2, 0xaa, 1, 0x55, 2, 0xaa, 1, 0x55, 2, 0xaa, 1, 0x55, 2, 0xaa, 1, 0x55, 2, 0xaa, 1, 0x55, 2, 0xaa, 1, 0x55, /* Char 178 */
     0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, /* Char 179 */
     0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 3, 0xf0, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, /* Char 180 */
     0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 3, 0xf0, 0, 0x10, 3, 0xf0, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, /* Char 181 */
     0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 3, 0xe8, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, /* Char 182 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 3, 0xf8, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, /* Char 183 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 3, 0xf0, 0, 0x10, 3, 0xf0, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, /* Char 184 */
     0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 3, 0xe8, 0, 0x08, 3, 0xe8, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, /* Char 185 */
     0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, /* Char 186 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 3, 0xf8, 0, 0x08, 3, 0xe8, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, /* Char 187 */
     0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 3, 0xe8, 0, 0x08, 3, 0xf8, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 188 */
     0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 3, 0xf8, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 189 */
     0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 3, 0xf0, 0, 0x10, 3, 0xf0, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 190 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 3, 0xf0, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, /* Char 191 */
     0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x1f, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 192 */
     0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 3, 0xff, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 193 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 3, 0xff, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, /* Char 194 */
     0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x1f, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, /* Char 195 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 3, 0xff, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 196 */
     0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 3, 0xff, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, /* Char 197 */
     0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x1f, 0, 0x10, 0, 0x1f, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, /* Char 198 */
     0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x2f, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, /* Char 199 */
     0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x2f, 0, 0x20, 0, 0x3f, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 200 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x3f, 0, 0x20, 0, 0x2f, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, /* Char 201 */
     0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 3, 0xef, 0, 0x00, 3, 0xff, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 202 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 3, 0xff, 0, 0x00, 3, 0xef, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, /* Char 203 */
     0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x2f, 0, 0x20, 0, 0x2f, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, /* Char 204 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 3, 0xff, 0, 0x00, 3, 0xff, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 205 */
     0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 3, 0xef, 0, 0x00, 3, 0xef, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, /* Char 206 */
     0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 3, 0xff, 0, 0x00, 3, 0xff, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 207 */
     0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 3, 0xff, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 208 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 3, 0xff, 0, 0x00, 3, 0xff, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, /* Char 209 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 3, 0xff, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, /* Char 210 */
     0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x3f, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 211 */
     0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x1f, 0, 0x10, 0, 0x1f, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 212 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x1f, 0, 0x10, 0, 0x1f, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, /* Char 213 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x3f, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, /* Char 214 */
     0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 3, 0xef, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, 0, 0x28, /* Char 215 */
     0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 3, 0xff, 0, 0x00, 3, 0xff, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, /* Char 216 */
     0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 3, 0xf0, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 217 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x1f, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, /* Char 218 */
     3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, /* Char 219 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, /* Char 220 */
     3, 0xe0, 3, 0xe0, 3, 0xe0, 3, 0xe0, 3, 0xe0, 3, 0xe0, 3, 0xe0, 3, 0xe0, 3, 0xe0, 3, 0xe0, 3, 0xe0, 3, 0xe0, 3, 0xe0, 3, 0xe0, 3, 0xe0, 3, 0xe0, 3, 0xe0, 3, 0xe0, /* Char 221 */
     0, 0x1f, 0, 0x1f, 0, 0x1f, 0, 0x1f, 0, 0x1f, 0, 0x1f, 0, 0x1f, 0, 0x1f, 0, 0x1f, 0, 0x1f, 0, 0x1f, 0, 0x1f, 0, 0x1f, 0, 0x1f, 0, 0x1f, 0, 0x1f, 0, 0x1f, 0, 0x1f, /* Char 222 */
     3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 3, 0xff, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 223 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0xe6, 1, 0xbc, 1, 0x98, 1, 0x98, 1, 0x98, 1, 0xbc, 0, 0xe6, 0, 0x00, 0, 0x00, /* Char 224 */
     0, 0x00, 0, 0x00, 0, 0xf0, 1, 0x98, 1, 0x8c, 1, 0x8c, 1, 0x8c, 1, 0x98, 1, 0xf0, 1, 0x98, 1, 0x8c, 1, 0x8c, 1, 0x8c, 1, 0x8c, 1, 0x8c, 1, 0xf8, 1, 0x80, 1, 0x80, /* Char 225 */
     0, 0x00, 0, 0xfe, 0, 0xfe, 0, 0xc6, 0, 0xc6, 0, 0xc0, 0, 0xc0, 0, 0xc0, 0, 0xc0, 0, 0xc0, 0, 0xc0, 0, 0xc0, 0, 0xc0, 0, 0xc0, 0, 0xc0, 0, 0xc0, 0, 0x00, 0, 0x00, /* Char 226 */
     0, 0x00, 0, 0x00, 1, 0xfe, 1, 0xfe, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0xcc, 0, 0x00, 0, 0x00, /* Char 227 */
     0, 0x00, 0, 0xfe, 0, 0xfe, 0, 0xc6, 0, 0xc6, 0, 0xe0, 0, 0x70, 0, 0x38, 0, 0x18, 0, 0x38, 0, 0x70, 0, 0xe0, 0, 0xc6, 0, 0xc6, 0, 0xfe, 0, 0xfe, 0, 0x00, 0, 0x00, /* Char 228 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x7f, 0, 0xff, 1, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0xce, 0, 0xfc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 229 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x8e, 1, 0xfe, 1, 0xf6, 1, 0x80, 1, 0x80, /* Char 230 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x06, 0, 0xee, 0, 0xfc, 0, 0x38, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 231 */
     0, 0xfc, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x78, 0, 0xfc, 1, 0xce, 1, 0x86, 1, 0x86, 1, 0xce, 0, 0xfc, 0, 0x78, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0xfc, 0, 0x00, 0, 0x00, /* Char 232 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0xfc, 0, 0xcc, 0, 0x84, 0, 0x84, 0, 0x84, 0, 0xfc, 0, 0xfc, 0, 0x84, 0, 0x84, 0, 0x84, 0, 0xcc, 0, 0xfc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 233 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x38, 0, 0x7c, 0, 0xee, 0, 0xc6, 0, 0xc6, 0, 0xc6, 0, 0xc6, 0, 0xee, 0, 0xee, 0, 0x6c, 0, 0x6c, 0, 0xee, 0, 0xee, 0, 0x00, 0, 0x00, /* Char 234 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x7c, 0, 0xfc, 0, 0xc0, 0, 0x60, 0, 0x30, 0, 0x18, 0, 0x7c, 0, 0xec, 0, 0xcc, 0, 0xcc, 0, 0xfc, 0, 0x78, 0, 0x00, 0, 0x00, /* Char 235 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0xcc, 1, 0xfe, 1, 0x32, 1, 0xfe, 0, 0xcc, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 236 */
     0, 0x00, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x78, 0, 0xfc, 1, 0xb6, 1, 0xb6, 1, 0xb6, 1, 0xb6, 1, 0xb6, 0, 0xfc, 0, 0x78, 0, 0x30, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, /* Char 237 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x3c, 0, 0x7c, 0, 0xe0, 0, 0xc0, 0, 0xc0, 0, 0xfc, 0, 0xfc, 0, 0xc0, 0, 0xc0, 0, 0xe0, 0, 0x7c, 0, 0x3c, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 238 */
     0, 0x00, 0, 0x00, 0, 0x78, 0, 0xcc, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 1, 0x86, 0, 0x00, 0, 0x00, /* Char 239 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0xfc, 0, 0xfc, 0, 0x00, 0, 0x00, 0, 0xfc, 0, 0xfc, 0, 0x00, 0, 0x00, 0, 0xfc, 0, 0xfc, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 240 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0xfc, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, 0, 0xfc, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 241 */
     0, 0x00, 0, 0xc0, 0, 0x60, 0, 0x30, 0, 0x18, 0, 0x0c, 0, 0x06, 0, 0x06, 0, 0x0c, 0, 0x18, 0, 0x30, 0, 0x60, 0, 0xc0, 0, 0x00, 0, 0xfe, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 242 */
     0, 0x00, 0, 0x04, 0, 0x0c, 0, 0x18, 0, 0x30, 0, 0x60, 0, 0xc0, 0, 0x80, 0, 0xc0, 0, 0x60, 0, 0x30, 0, 0x18, 0, 0x0c, 0, 0x00, 1, 0xfe, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 243 */
     0, 0x00, 0, 0x0c, 0, 0x12, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, /* Char 244 */
     0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x10, 0, 0x90, 0, 0x90, 0, 0x60, 0, 0x00, 0, 0x00, /* Char 245 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x00, 1, 0xfe, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 246 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0xc0, 1, 0xf2, 1, 0x3e, 0, 0x0c, 0, 0xc0, 1, 0xf2, 1, 0x3e, 0, 0x0c, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 247 */
     0, 0x00, 0, 0x70, 0, 0xd8, 1, 0x8c, 1, 0x8c, 0, 0xd8, 0, 0x70, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 248 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x78, 0, 0xfc, 0, 0xfc, 0, 0xfc, 0, 0xfc, 0, 0x78, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 249 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x30, 0, 0x30, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 250 */
     0, 0x00, 0, 0x1f, 0, 0x1f, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 0, 0x18, 1, 0xd8, 1, 0xd8, 0, 0x78, 0, 0x78, 0, 0x38, 0, 0x18, 0, 0x08, 0, 0x00, 0, 0x00, /* Char 251 */
     0, 0xf0, 0, 0xd8, 0, 0xd8, 0, 0xd8, 0, 0xd8, 0, 0xd8, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 252 */
     0, 0x70, 0, 0xd8, 0, 0x30, 0, 0x60, 0, 0xc0, 0, 0xf8, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 253 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x78, 0, 0x78, 0, 0x78, 0, 0x78, 0, 0x78, 0, 0x78, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, /* Char 254 */
     0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00, 0, 0x00};/* Char 255 */
